import { GraphQLField, Source, GraphQLResolveInfo } from "graphql";
import { GQLField } from "./GQLField";
import { ResolveFunction } from "../../types/ResolveFunction";
import { FieldType } from "../../types/FieldType";
import { Arg } from "./Arg";
import { Removable } from "../../helpers/ArrayHelper";
import { Middleware } from "../middlewares/Middleware";
import { Args } from "./Args";
import { ClassType } from "../../../shared/ClassType";
import { Resolver } from "../../types/Resolver";
import { KeyValue } from "../../../shared/KeyValue";
import { InputFieldType } from "../../types/InputFieldType";
export declare class Field extends GQLField<GraphQLField<any, any, any>> {
    private _args;
    private _resolve;
    private _middlewares;
    get args(): (Arg<string> | Args<any>)[];
    get flatArgs(): Arg<string>[];
    get resolve(): ResolveFunction<KeyValue>;
    static create(name: string, type: FieldType): Field;
    setMiddlewares(...middlewares: Middleware[]): this;
    addMiddlewares(...middlewares: Middleware[]): this;
    removeMiddlewares(...middlewares: Removable<Middleware>): this;
    setArgs(...args: (Arg | Args)[]): this;
    addArg<NameType = string>(arg: Arg<NameType>): any;
    addArg<NameType = string>(name: NameType, type: InputFieldType): any;
    addArgs(...args: (Arg | Args)[]): this;
    removeArgs(...args: Removable<Arg>): this;
    setResolver<ResolverType extends Resolver<any>>(resolver: ClassType<ResolverType>, ...args: (Arg<keyof ResolverType> | Args<ClassType<ResolverType>>)[]): this;
    setResolve<ArgsType = KeyValue>(resolve: ResolveFunction<ArgsType>, ...args: (Arg | Args)[]): this;
    build(): GraphQLField<any, any, any>;
    resolveField(source: Source, args: any, context: any, infos: GraphQLResolveInfo): Promise<any>;
}
