"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Field_1 = require("./Field");
const TypeParser_1 = require("../../helpers/TypeParser");
class ObjectField extends Field_1.Field {
    constructor() {
        super(...arguments);
        this._args = [];
        this._middlewares = [];
    }
    get args() {
        return this._args;
    }
    get resolve() {
        return this._resolve;
    }
    static create(name, type) {
        return new ObjectField(name, type);
    }
    addMiddlewares(...middlewares) {
        this._middlewares = [...this._middlewares, ...middlewares];
        return this;
    }
    setResolve(resolve, ...args) {
        this._args = args.flatMap((a) => a);
        this._resolve = resolve;
        return this;
    }
    build() {
        const args = this._args.map((arg) => arg.build());
        this.addMiddleware(this.resolve);
        const field = {
            name: this._name,
            type: TypeParser_1.TypeParser.parse(this._type),
            resolve: this.resolveField,
            deprecationReason: this._deprecationReason || null,
            isDeprecated: !!this._deprecationReason,
            args,
            description: this._description,
            extensions: [],
        };
        this._built = field;
        return { ...this._built };
    }
    async resolveField(source, args, context, infos) {
        const next = async (args, gql, index, paramsToNext) => {
            const nextFn = () => next(args, gql, index + 1, paramsToNext);
            const guardToExecute = this._middlewares[index];
            const res = await guardToExecute(args, gql, nextFn, paramsToNext);
            if (res) {
                return res;
            }
            return paramsToNext;
        };
        return await next(args, {
            source,
            context,
            infos,
        }, 0, {});
    }
}
exports.ObjectField = ObjectField;
//# sourceMappingURL=ObjectField.js.map