"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const Wrapper_1 = require("../../../wrapper/Wrapper");
const GraphQLElement_1 = require("../../types/GraphQLElement");
const ArrayHelper_1 = require("../../helpers/ArrayHelper");
class Schema extends GraphQLElement_1.GraphQLElement {
    constructor() {
        super();
        this._types = [];
    }
    setTypes(...types) {
        this._types = [
            ...types.flatMap((item) => {
                if (item instanceof Wrapper_1.Wrapper) {
                    return item.types;
                }
                return item;
            }),
        ];
        return this;
    }
    addTypes(...types) {
        return this.setTypes(...this._types, ...types);
    }
    removeTypes(...types) {
        return this.setTypes(...ArrayHelper_1.ArrayHelper.remove(types, this._types));
    }
    build() {
        const types = this._types.map((t) => [
            t.name,
            t.build(),
        ]);
        const typesMap = new Map(types);
        const query = typesMap.get("Query");
        const mutation = typesMap.get("Mutation");
        const subscription = typesMap.get("Subscription");
        this._built = new graphql_1.GraphQLSchema({
            query,
            mutation,
            subscription,
            types: types.map((t) => t[1]),
            description: this._description,
        });
        return this._built;
    }
    static create(...types) {
        const schema = new Schema();
        schema.setTypes(...types);
        return schema;
    }
}
exports.Schema = Schema;
//# sourceMappingURL=Schema.js.map