"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ComposedType_1 = require("./composed/ComposedType");
const NotNullable_1 = require("../modifiers/NotNullable");
const ArrayHelper_1 = require("../../helpers/ArrayHelper");
class GQLType extends ComposedType_1.ComposedType {
    constructor(name) {
        super(name);
        this._fields = [];
        this._hidden = false;
    }
    get fields() {
        return this._fields;
    }
    get hidden() {
        return this._hidden;
    }
    setFields(...fields) {
        this._fields = fields;
        return this;
    }
    addFields(...fields) {
        return this.setFields(...this._fields, ...fields);
    }
    removeFields(...fields) {
        return this.setFields(...ArrayHelper_1.ArrayHelper.remove(fields, this._fields));
    }
    setExtension(extension) {
        this._extension = extension;
        return this;
    }
    setHidden(hidden) {
        this._hidden = hidden;
        return this;
    }
    partial() {
        this.transformFields((field) => {
            if (field.type instanceof NotNullable_1.NotNullableType) {
                field.setType(field.type.type);
            }
            return {};
        });
        return this;
    }
    required() {
        this.transformFields((field) => {
            if (!(field.type instanceof NotNullable_1.NotNullableType)) {
                field.setType(NotNullable_1.NotNullable(field.type));
            }
            return {};
        });
        return this;
    }
    preBuild() {
        var _a;
        this._fields = [...this._fields, ...(((_a = this._extension) === null || _a === void 0 ? void 0 : _a._fields) || [])];
        return this;
    }
    toConfigMap(arr) {
        return arr.reduce((prev, item) => {
            const built = item.build();
            prev[built.name] = {
                ...built,
            };
            return prev;
        }, {});
    }
    applyFieldsTransformation(cb) {
        return this.fields.map((field) => {
            cb(field);
        });
    }
}
exports.GQLType = GQLType;
//# sourceMappingURL=GQLType.js.map