"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const GQLType_1 = require("./GQLType");
const TypeConverter_1 = require("../../helpers/TypeConverter");
const TypeResolver_1 = require("../../helpers/TypeResolver");
class InterfaceType extends GQLType_1.GQLType {
    constructor(name) {
        super(name);
        this.setTypeResolver(this.defaultTypeResolver);
    }
    get fields() {
        return this._fields;
    }
    static create(name) {
        return new InterfaceType(name);
    }
    setTypeResolver(typeResolver) {
        this._typeResolver = typeResolver;
        return this;
    }
    build() {
        this.preBuild();
        const interf = {
            name: this.name,
            description: this.description,
            resolveType: this._typeResolver,
            getFields: () => {
                return this.toConfigMap(this.fields);
            },
            getInterfaces: () => [this.built],
            toConfig: undefined,
            toJSON: undefined,
            inspect: undefined,
            extensionASTNodes: [],
            extensions: [],
        };
        this._built = interf;
        return this._built;
    }
    convert(to) {
        return TypeConverter_1.TypeConverter.convert(this, to);
    }
    copy() {
        return InterfaceType.create(this.name)
            .setDescription(this._description)
            .setHidden(this._hidden)
            .setExtension(this._extension)
            .addFields(...this._fields);
    }
    transformFields(cb) {
        this.applyFieldsTransformation(cb);
        return this;
    }
    defaultTypeResolver(obj) {
        return TypeResolver_1.TypeResolver.resolve(obj, []);
    }
}
exports.InterfaceType = InterfaceType;
//# sourceMappingURL=InterfaceType.js.map