"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const GQLType_1 = require("./GQLType");
const graphql_1 = require("graphql");
const TypeConverter_1 = require("../../helpers/TypeConverter");
class ObjectType extends GQLType_1.GQLType {
    constructor() {
        super(...arguments);
        this._fields = [];
        this._implementations = [];
    }
    get fields() {
        return this._fields;
    }
    get implementations() {
        return this._implementations;
    }
    setImplementations(...implementations) {
        this._implementations = implementations;
        return this;
    }
    addImplementations(...implementations) {
        this.setImplementations(...this._implementations, ...implementations);
        return this;
    }
    removeImplementation(type) {
        this._implementations.splice(this._implementations.indexOf(type), 1);
        return this;
    }
    static create(name) {
        return new ObjectType(name);
    }
    build() {
        this.preBuild();
        this._fields = [
            ...this._fields,
            ...this._implementations.flatMap((i) => i.fields),
        ];
        const built = new graphql_1.GraphQLObjectType({
            name: this._name,
            description: this.description,
            fields: () => {
                return this.fields.reduce((prev, field) => {
                    const built = field.build();
                    const argMap = this.toConfigMap(field.flatArgs);
                    delete built.isDeprecated;
                    prev[built.name] = {
                        ...built,
                        args: argMap,
                    };
                    return prev;
                }, {});
            },
            interfaces: () => this.implementations.map((i) => i.built),
        });
        this._built = built;
        return built;
    }
    convert(to) {
        return TypeConverter_1.TypeConverter.convert(this, to);
    }
    copy() {
        return ObjectType.create(this.name)
            .setDescription(this._description)
            .setHidden(this._hidden)
            .setImplementations(...this._implementations)
            .setExtension(this._extension)
            .addFields(...this._fields);
    }
    transformFields(cb) {
        this.applyFieldsTransformation(cb);
        return this;
    }
}
exports.ObjectType = ObjectType;
//# sourceMappingURL=ObjectType.js.map