"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const GraphQLElement_1 = require("../../../types/GraphQLElement");
const graphql_1 = require("graphql");
const ComposedType_1 = require("./ComposedType");
const TypeResolver_1 = require("../../../helpers/TypeResolver");
const ArrayHelper_1 = require("../../../helpers/ArrayHelper");
class UnionType extends ComposedType_1.ComposedType {
    constructor(name) {
        super(name);
        this._types = [];
        this._typeResolver = this.defaultTypeResolver;
    }
    static create(name) {
        return new UnionType(name);
    }
    setTypeResolver(typeResolver) {
        this._typeResolver = typeResolver;
        return this;
    }
    setTypes(...types) {
        this._types = types;
        return this;
    }
    addTypes(...types) {
        return this.setTypes(...this._types, ...types);
    }
    removeTypes(...types) {
        return this.setTypes(...ArrayHelper_1.ArrayHelper.remove(types, this._types));
    }
    copy() {
        return UnionType.create(this.name).addTypes(...this._types);
    }
    build() {
        return new graphql_1.GraphQLUnionType({
            name: this.name,
            resolveType: this._typeResolver,
            description: this._description,
            types: () => {
                return GraphQLElement_1.GraphQLElement.built(this._types);
            },
            extensions: [],
        });
    }
    defaultTypeResolver(obj) {
        return TypeResolver_1.TypeResolver.resolve(obj, this._types);
    }
}
exports.UnionType = UnionType;
//# sourceMappingURL=UnionType.js.map