"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const ComposedType_1 = require("../ComposedType");
const ArrayHelper_1 = require("../../../../helpers/ArrayHelper");
class EnumType extends ComposedType_1.ComposedType {
    constructor() {
        super(...arguments);
        this._values = [];
    }
    static create(name) {
        return new EnumType(name);
    }
    setValues(...values) {
        this._values = values;
        return this;
    }
    addValues(...values) {
        return this.setValues(...this._values, ...values);
    }
    removeValues(...values) {
        return this.setValues(...ArrayHelper_1.ArrayHelper.remove(values, this._values));
    }
    copy() {
        return EnumType.create(this.name).addValues(...this._values);
    }
    build() {
        const values = this._values.reduce((prev, value) => {
            prev[value.name] = value.build();
            delete prev[value.name]["isDeprecated"];
            return prev;
        }, {});
        this._built = new graphql_1.GraphQLEnumType({
            name: this.name,
            description: this._description,
            values,
        });
        return this.built;
    }
}
exports.EnumType = EnumType;
//# sourceMappingURL=EnumType.js.map