"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ObjectType_1 = require("../graphql/defintion/types/ObjectType");
const InterfaceType_1 = require("../graphql/defintion/types/InterfaceType");
const Field_1 = require("../graphql/defintion/fields/Field");
const InputField_1 = require("../graphql/defintion/fields/InputField");
const InputType_1 = require("../graphql/defintion/types/InputType");
const ClassDescriptor_1 = require("../graphql/helpers/ClassDescriptor");
const GQLField_1 = require("../graphql/defintion/fields/GQLField");
const GQLType_1 = require("../graphql/defintion/types/GQLType");
class Wrapper {
    constructor(...types) {
        this._types = [];
        this.addTypes(...types);
    }
    get types() {
        return this._types;
    }
    static create(...types) {
        const wrapper = new Wrapper(...types);
        return wrapper;
    }
    addTypes(...types) {
        this._types = [...this._types, ...types];
        return this;
    }
    addMiddlewares(...middlewares) {
        this.transformFields(Field_1.Field, (f) => {
            f.addMiddlewares(...middlewares);
        });
    }
    transform(toTransform, cb) {
        this._types.map((t) => {
            if (ClassDescriptor_1.ClassDescriptor.instanceOf(t, toTransform)) {
                cb(t);
            }
        });
    }
    transformFields(fieldType, cb) {
        const fieldTypeMap = new Map([
            [Field_1.Field, [ObjectType_1.ObjectType, InterfaceType_1.InterfaceType]],
            [InputField_1.InputField, [InputType_1.InputType]],
            [GQLField_1.GQLField, [GQLType_1.GQLType]],
        ]);
        fieldTypeMap.get(fieldType).map((ot) => {
            this.transform(ot, (t) => {
                t.fields.map((f) => {
                    cb(f);
                });
            });
        });
    }
}
exports.Wrapper = Wrapper;
//# sourceMappingURL=Wrapper.js.map